@@ -5,7 +5,8 @@
 ##' @rdname NMsimResOperations
 unNMsimRes <- function(x){
     if(!is.null(x)){
-        setattr(x,"NMsimRes",NULL)
+        ## setattr(x,"NMsimRes",NULL)
+        setattr(x,"NMsimModTab",NULL)
         setattr(x,"class",setdiff(class(x),"NMsimRes"))
     }
 }
@@ -62,17 +63,20 @@ dimnames.NMsimRes <- function(x,...){
 ##' @export
 rbind.NMsimRes <- function(x,...){
     
-    list.ModTab <- lapply(c(x,list(...)),function(y)attributes(y)$NMsimModTab)
+    list.ModTab <- lapply(c(list(x),list(...)),function(y)attributes(y)$NMsimModTab)
     ## list.ModTab <- list.ModTab[!sapply(list.ModTab,is.null)]
     ModTab <- rbindlist(list.ModTab,fill=TRUE)
 
-    ## unNMsimRes(x)
-    lapply(c(x,list(...)),unNMsimRes)
-
+### solution 1
+    unNMsimRes(x)
+    ## lapply(c(x,list(...)),unNMsimRes)
+    res <- rbind(x,...)
+    
     ## args.res.list <- c(x,list(...))
     ## args.res.list <- args.res.list[!sapply(args.res.list,is.null)]
     ## res <- do.call(rbind,args.res.list)
-    res <- rbind(x,...)
+### solution 2
+    ## res <- data.table:::rbind.data.table(x,...)
 
     addClass(res,"NMsimRes")
     setattr(res,"NMsimModTab",ModTab)
